@@ -1,13 +1,16 @@
 #
 # This file is part of Config-Model-LcdProc
 #
-# This software is Copyright (c) 2013-2017 by Dominique Dumont.
+# This software is Copyright (c) 2013-2021 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-[
+use strict;
+use warnings;
+
+return [
   {
     'class_description' => '
 
@@ -948,13 +951,12 @@ Model information was extracted from /etc/LCDd.conf',
     ],
     'license' => 'GPL-2',
     'name' => 'LCDd',
-    'read_config' => [
-      {
-        'backend' => 'IniFile',
-        'config_dir' => '/etc',
-        'file' => 'LCDd.conf'
-      }
-    ]
+    'rw_config' => {
+      'backend' => 'IniFile',
+      'config_dir' => '/etc',
+      'file' => 'LCDd.conf',
+      'quote_value' => 'shell_style'
+    }
   }
 ]
 ;
